/*
 * Copyright (C) 2023 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

syntax = "proto2";

package android.os.statsd.settings;

import "frameworks/proto_logging/stats/atoms.proto";
import "frameworks/proto_logging/stats/atom_field_options.proto";
import "frameworks/proto_logging/stats/enums/app/settings_enums.proto";

option java_package = "com.android.os.settings";
option java_multiple_files = true;

extend Atom {
  optional SettingsSpaReported settings_spa_reported = 622 [(module) = "settings"];
}


/**
 * Logs when Settings SPA UI has changed.
 *
 * Logged from:
 *   packages/apps/Settings
 */
message SettingsSpaReported {
  // Settings SPA session type.
  optional android.app.settings.SessionType session_type = 1;

  // The id value of SettingsPage.
  optional string page_id = 2;

  // The id value of target page.
  optional string target = 3;

  // What the UI action is.
  optional android.app.settings.Action action = 4;

  // The value of entry id
  optional string key = 5;

  // The value of any type (string, int, boolean etc),
  // cast the value into string type.
  optional string value = 6;

  // Keeps the previous value while data changing.
  optional string previous_value = 7;

  // Data about elapsed time since setup wizard finished.
  optional int64 elapsed_time_millis = 8;
}